<?php

namespace Litepie\User\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\User\Models\Client;

class ClientPolicy
{

    /**
     * Determine if the given user can view the client.
     *
     * @param UserPolicy $user
     * @param Client $client
     *
     * @return bool
     */
    public function view(UserPolicy $user, Client $client)
    {
        if ($user->canDo('user.client.view') && $user->isAdmin()) {
            return true;
        }

        return $client->user_id == user_id() && $client->user_type == user_type();
    }

    /**
     * Determine if the given user can create a client.
     *
     * @param UserPolicy $user
     * @param Client $client
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('user.client.create');
    }

    /**
     * Determine if the given user can update the given client.
     *
     * @param UserPolicy $user
     * @param Client $client
     *
     * @return bool
     */
    public function update(UserPolicy $user, Client $client)
    {
        if ($user->canDo('user.client.edit') && $user->isAdmin()) {
            return true;
        }

        return $client->user_id == user_id() && $client->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given client.
     *
     * @param UserPolicy $user
     * @param Client $client
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Client $client)
    {
        return $client->user_id == user_id() && $client->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given client.
     *
     * @param UserPolicy $user
     * @param Client $client
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Client $client)
    {
        if ($user->canDo('user.client.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given client.
     *
     * @param UserPolicy $user
     * @param Client $client
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Client $client)
    {
        if ($user->canDo('user.client.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
